#
#  FILE NAME:
#      class_renamed.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import logging
import warnings


_LOG = logging.getLogger( "p3.base" )


class ClassRenamed( object ):
    def __init__( self, srcClassName, dstClass ):
        self.srcClsName = srcClassName
        self.dstCls     = dstClass

    def _IssueWarning( self ):
        msg = ("The '{0:s}' class was renamed to '{1:s}'. '{0:s}' is currently an alias and will"
               " be removed in one of future releases."
               "".format( self.srcClsName, self.dstCls.__name__ ))
        _LOG.warning( msg )
        warnings.warn( msg, DeprecationWarning, 3 )

    def __call__( self, *args, **kwargs ):
        self._IssueWarning()

        return self.dstCls( *args, **kwargs )

    def __getattr__( self, attr ):
        self._IssueWarning()
        return getattr( self.dstCls, attr )
