#
#  FILE NAME:
#      date_helpers.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import datetime

# Convert a date (year, 1, 1), expressed in the year-week-day reference system to a date expressed
#  in the year-month-day reference system.
def ConvertYwdYearToYmdDate( year ):
    # ISO 8601 says:
    #     [...] A calendar week is identified within a calendar year by the calendar week number.
    #     This is its ordinal position within the year, applying the rule that the first calendar
    #     week of a year is the one that includes the first Thursday of that year.

    # Last possible YMD date representing following YWD date: (year, 1, 1).
    base = datetime.date( year, 1, 4 )
    # Determine offset necessary to "fix" YWD date from (year, 1, x) to (year, 1, 1):
    offset = datetime.timedelta( days=base.isoweekday()-1 )
    return base - offset


def ConvertYwdDateToYmdDate( year, week, day ):
    return ConvertYwdYearToYmdDate( year ) + datetime.timedelta( weeks=week-1, days=day-1 )
