#
#  FILE NAME:
#      exception.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# P3 imports
from p3.base.string_helpers import AnyStr, UniStr


class GenericException( Exception ):
    def __init__( self, moduleName=None, errorCode=None, errorMessage=None ):
        self.moduleName   = self._SanitizeStr( moduleName )
        self.errorCode    = self._SanitizeInt( errorCode )
        self.errorMessage = self._SanitizeStr( errorMessage )


    #* If the attribute is narrow or wide string, convert it to narrow string.
    #  Otherwise return None.
    @classmethod
    def _SanitizeStr( cls, s ):
        if isinstance( s, basestring ):
            return UniStr( s )
        else:
            return None


    @classmethod
    def _SanitizeInt( cls, i ):
        if isinstance( i, int ):
            return i
        else:
            return None


    def __str__( self ):
        return ("%s#%s%s" % (
                ('?' if self.moduleName is None else self.moduleName),
                ('?' if self.errorCode is None else str(self.errorCode)),
                ('' if self.errorMessage is None else ': %s' % self.errorMessage)))


class BaseModuleError( GenericException ):
    class codes(object):
        enumDefinitionError = 1
        enumConstError      = 2
        invalidImportPath   = 4
        requiredModuleNotAvailable = 5

    def __init__( self, code=None, msg=None ):
        super( BaseModuleError, self ).__init__( "base", code, msg )
