#
#  FILE NAME:
#      version_info.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import logging
import unittest


_LOG = logging.getLogger( "tests" )


class VersionInfo( object ):
    def __init__( self, major, minor, micro=0, releaseLevel='final', serial=0 ):
        rlLut = { 'alpha': 0xA,
                  'beta':  0xB,
                  'rc':    0xC,
                  'final': 0xF }

        rl = rlLut.get( releaseLevel )

        assert rl is not None
        assert 0x00 <= major <= 0xFF
        assert 0x00 <= minor <= 0xFF
        assert 0x00 <= micro <= 0xFF
        assert 0x0 <= serial <= 0xF

        self._major = major
        self._minor = minor
        self._micro = micro
        self._level = releaseLevel
        self._serial = serial
        self._hex = ((((((((major << 8) | minor) << 8) | micro) << 4) | rl) << 4) | serial)

    def __str__( self ):
        serial = ("-{0:d}".format( self._serial ) if self._serial else "")
        return ("{0:d}.{1:d}.{2:d} ({3:s}{4:s})"
                "".format( self._major, self._minor, self._micro, self._level.upper(), serial ))

    def major():
        def fget( self ):
            return self._major
        return locals()
    major = property(**major())

    def minor():
        def fget( self ):
            return self._minor
        return locals()
    minor = property(**minor())

    def micro():
        def fget( self ):
            return self._micro
        return locals()
    micro = property(**micro())

    def releaselevel():
        def fget( self ):
            return self._level
        return locals()
    releaselevel = property(**releaselevel())

    def serial():
        def fget( self ):
            return self._serial
        return locals()
    serial = property(**serial())

    def hex():
        def fget( self ):
            return self._hex
        return locals()
    hex = property(**hex())
