#
#  FILE NAME:
#      logger.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard imports:
import logging.config
import StringIO

# P3 imports:
from p3.conf.error import ConfModuleError

## Load configFile and format it to replace LOG_OUTPUT_FILE formatting directive with value of
#  outputFile parameter. Note, that any '%' characters which aren't supposed to be interpreted as
#  formatting directives in this process (e.g. used in datefmt or format options) have to be
#  escaped (doubled).
def ConfigureLoggingModule( configFile, outputFile ):
    cfgTemplate = open( configFile ).read()
    cfgString = cfgTemplate % { 'LOG_OUTPUT_FILE': outputFile }
    logging.config.fileConfig( StringIO.StringIO( cfgString ) )

## High level, standarized logger configuration function purposed to retrieve all logger related
#  configuration data from provided settings object and properly initialize logging module with it.
#
#  Currently the function attempts to retrieve logger configuration and output file names and
#  passes it to the ConfigureLoggingModule function if successful.
def ConfigureLogger( settings ):
    logOutputFile = settings.GetSetting( "LOG_OUTPUT_FILE" )

    if logOutputFile is None:
        raise ConfModuleError( ConfModuleError.codes.unspecifiedLogOutputFile,
                               "Specified settings module doesn't define 'LOG_OUTPUT_FILE'"
                               " setting." )

    logConfigFile = settings.GetSetting( "LOG_CONFIG_TEMPLATE_FILE" )

    if logConfigFile is None:
        raise ConfModuleError( ConfModuleError.codes.unspecifiedLogConfigFile,
                               "Specified settings module doesn't define"
                               "'LOG_CONFIG_TEMPLATE_FILE' setting." )

    ConfigureLoggingModule( logConfigFile, logOutputFile )
