#
#  FILE NAME:
#      operations.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# P3 imports:
from p3.base.string_helpers import SafeFmt
from p3.data.error import DataModuleError


def FindRowOpt( table, expr=None ):
    rows = (table.rows if expr is None else table.FindRows( expr ))
    cnt = len(rows)
    if (cnt > 1):
        raise DataModuleError( DataModuleError.codes.multipleRowsFound,
                               SafeFmt( "Multiple rows found for expression: %s", repr(expr) ) )
    else:
        return (rows[0] if cnt else None)


def FindRowReq( table, expr=None ):
    rows = (table.rows if expr is None else table.FindRows( expr ))
    cnt = len(rows)
    if (cnt > 1):
        raise DataModuleError( DataModuleError.codes.multipleRowsFound,
                               SafeFmt( "Multiple rows found for expression: %s", repr(expr) ) )
    elif not cnt:
        raise DataModuleError( DataModuleError.codes.rowNotFound,
                               SafeFmt( "Required row not found with expression: %s", repr(expr) ))
    else:
        return rows[0]


def ExtractColumnValues( table, colSpec ):
    col = table.ResolveColumns( colSpec )[0]

    return tuple(r[col.index] for r in table.rows)
