#
#  FILE NAME:
#      index_transform.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import logging

# P3 imports:
from p3.data.error import DataModuleError


_LOG = logging.getLogger( "p3.data" )


def IndexTransform( srcTable, dstTable, indexCols, transformCb ):
    srcColIdx = [c.index for c in srcTable.ResolveColumns( *indexCols )]
    rowLut = {}

    def MakeKey( row, colIdx ):
        return tuple(row[i] for i in colIdx)

    for srcRow in srcTable.rows:
        dstRow = rowLut.get( MakeKey(srcRow, srcColIdx) )
        newRow = transformCb( srcRow, dstRow, dstTable )

        if dstRow is None:
            rowLut[MakeKey(srcRow, srcColIdx)] = newRow
