#
#  FILE NAME:
#      enum_converter.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import logging
import re

# P3 imports:
from p3.base import Enum, SafeFmt
from p3.logic.var.converter.conversion_result import ConversionResult

_LOG = logging.getLogger( "p3.logic" )


class EnumConverter( object ):
    errors = Enum( "formatError", "emptyInput", "valueError" )

    ## ===[ Initialization ]==================================================================== ##

    def __init__( self, enum ):
        self.enum = enum


    ## ===[ Conversion ]======================================================================== ##

    def Deserialize( self, value ):
        if not isinstance( value, basestring ):
            raise TypeError( SafeFmt( "EnumConverter.Deserialize methods expects basestring as its"
                                      " parameter (got %s instead).", type(value) ) )

        res = ConversionResult( value, self.__class__ )

        if not value:
            res.errors.append( self.errors.emptyInput )
            return res

        m = re.match( "^-{0,1}[1-9]{1}[0-9]*$|^0$", value )

        if m is not None:
            outVal = int(m.group(0))

            if outVal in self.enum:
                res.outVal = outVal
            else:
                res.errors.append( self.errors.valueError )
        else:
            res.errors.append( self.errors.formatError )

        return res
