#
#  FILE NAME:
#      separate_database_case.py
#
#  AUTHOR(S):
#      Dariusz Walczak <dariusz.walczak@gmail.com>
#

# Standard library imports:
import logging
import unittest

# P3 imports:
from p3.db import DbConnection
from p3.db.manage import CreateDb, DropDb


_LOG = logging.getLogger( "p3.test" )


# Used when separate, clean database is expected by each of cases.
class SeparateDatabaseCase( unittest.TestCase ):
    def __init__( self, caseName ):
        super( SeparateDatabaseCase, self ).__init__( caseName )

        self._caseName = caseName
        self.mngDbc = None
        self.tstDbc = None


    def GetManagementDbSpec( self ):
        return self.MANAGEMENT_DB_SPEC


    def GetTestDbSpec( self ):
        return self.TEST_DB_SPEC


    def setUp( self ):
        self.mngDbc = DbConnection.CreateFromDict( self.GetManagementDbSpec() )
        testDbSpec = self.GetTestDbSpec()
        dbName = testDbSpec.get('name')
        CreateDb( self.mngDbc, dbName, True )
        self.tstDbc = DbConnection.CreateFromDict( testDbSpec )


    def tearDown( self ):
        dbName = self.tstDbc.dbName
        self.tstDbc = None
        DropDb( self.mngDbc, dbName )
        self.mngDbc = None
        
